<?php
/**
 * @package Keyinvoice
 */

 namespace KeyinvoiceWordpress\Admin;
 use KeyinvoiceWordpress\API\Keyinvoice;

 class Orders
 {
    public $option_name = 'keyinvoice';

    function register()
    { 
		add_action( 'add_meta_boxes', [$this, 'add_meta_boxesws'] );

		add_action('woocommerce_checkout_update_order_meta',[$this,'vat_checkout']);
		add_action('woocommerce_thankyou', [$this,'ki_checkout_save_user_meta'] );

		add_filter('woocommerce_checkout_fields',[$this,'add_vat_field_checkout']);
		add_filter('woocommerce_billing_fields', [$this,'my_area_billing_field'] ,50,40);

		add_filter('woocommerce_customer_meta_fields',[$this,'add_vat_field']);
		add_filter('woocommerce_admin_billing_fields',[$this,'show_vat_field_order']);

		add_action('admin_menu',[$this,'generate_pdf']);
    }

	function add_meta_boxesws()
	{
		add_meta_box($this->option_name.'_add_meta_box', 'Keyinvoice', array( $this, $this->option_name.'_make_box_generate'), 'shop_order', 'side', 'core');
	}

    function keyinvoice_make_box_generate($post)
    {
    	$order = wc_get_order( $post->ID );
    	$document = get_post_meta( $order->get_id(), '_keyinvoice_document_id', true );
		
    	if($document == '')
    	{
    		if($order->get_status() == 'processing' || $order->get_status() == 'completed')
	    	{

	    		echo '<button class="button button-primary btn-generate-document">'.__('Gerar Documento').'</button>';
	    		echo '<div class="lds-ring"><div></div><div></div><div></div><div></div></div>';
	    		echo '<div class="result-generate"></div>';
	    	}else
			{

	    		echo '<div class="" style="margin:0">
				    	'.__('A encomenda tem que ser dada como processada/completa para poder ser gerada.').'
					 </div>';
	    	}

    	}else{

    		echo __("O documento já foi gerado no sistema de faturação.");
    		echo '<div class="pad-10"><a href="'.admin_url('admin.php?page=generate-pdf&order_id='.$order->get_id()).'" class="button button-primary">Descarregar PDF</a></div>';
    		echo '<div class="pad-10"><button class="button  btn-generate-document">'.__('Gerar novamente o Documento').'</button></div>';
    		echo '<div class="lds-ring"><div></div><div></div><div></div><div></div></div>';
	    	echo '<div class="result-generate"></div>';
    	}	


    }

	public function vat_checkout( $order_id ) 
	{
		$order = wc_get_order( $order_id );
		if ( isset( $_POST['keyinvoice_vat_field_code'] ) && ! empty( $_POST['keyinvoice_vat_field_code'] ) ) {
			$order->update_meta_data( '_billing_keyinvoice_vat_field_code', sanitize_text_field( $_POST['keyinvoice_vat_field_code'] ) );
		}
		$order->save();
	}


	public function ki_checkout_save_user_meta($order_id)
	{

		$order = new \WC_Order( $order_id );
	    $user_id = $order->get_user_id();
	    
		$vat = $order->get_meta( '_billing_keyinvoice_vat_field_code' );
		update_user_meta( $user_id, 'keyinvoice_vat_field_code', $vat);
		  
	}

	public function my_area_billing_field($fields)
	{
		$fields['keyinvoice_vat_field_code'] = array(
		   'label'    => __( 'Contribuinte (Keyinvoice)', 'keyinvoice' ),
		   'required'    => false,             
		   'clear'       => true,             
		   'type'        => 'text',                
		   'class'       => array('own-css-name')
	    );

 		return $fields;
	}


	public function add_vat_field_checkout($fields)
	{
		global $current_user;

		$fields['billing']['keyinvoice_vat_field_code'] = array(
			'label'    => __( 'Contribuinte', 'keyinvoice' ),
			'required' => 0,
			'type'     => 'text',
			'class'    => array(
				'form-row-wide',
			),
			'clear'    => true,
			'default'  => get_user_meta( $current_user->ID, 'keyinvoice_vat_field_code', true ),
			'priority' => 120,
		);
		return $fields;
	}
	

	public function add_vat_field($fields)
	{
		$fields['billing']['fields']['keyinvoice_vat_field_code'] = array(
			'label'       => __('Contribuinte (Keyinvoice)', 'keyinvoice' ),
			'required'    => 0 ,
			'type'        => 'text',
			'description' => __( 'Contribuinte que faz a ligação com o keyinvoice',  'keyinvoice' ),
		);

		return $fields;
	}

	public function show_vat_field_order($fields)
	{
		$fields['keyinvoice_vat_field_code'] = array(
			'label'    => __('Contribuinte (Keyinvoice)', 'keyinvoice' ),
			'required' => 0,
			'type'     => 'text',
			'class'    => 'short',
			'wrapper_class' => 'form-field form-field-wide',
		);

		return $fields;	

	}

	public function generate_pdf()
	{
		add_submenu_page (
	        '',
	        '',
	        '',
	        'manage_options',
	       
	        'generate-pdf',
	        [$this,'pdf_page']
    	);
	}

	public function pdf_page()
	{
		$order_id = $_REQUEST['order_id'];
		$order = wc_get_order( $order_id );
    	$document = get_post_meta( $order->id, '_keyinvoice_document_id', true );	

    	if(trim($document) != '')
    	{
			$soap = new Keyinvoice( get_option( 'url_api') );
			$soap->authenticate( get_option( 'api_key') );
			$result = $soap->getPDFLink( $document );

    		$keyinvoice_document_ids = explode('_',$document);

    		header("Expires: 0");
			header("Cache-Control: no-cache, no-store, must-revalidate"); 
			header('Cache-Control: pre-check=0, post-check=0, max-age=0', false); 
			header("Pragma: no-cache");	
			header("Content-type: application/pdf");
			header('Content-Disposition: attachment; filename="'.$keyinvoice_document_ids[1].$keyinvoice_document_ids[2].$keyinvoice_document_ids[0].'.pdf"');
			header("Content-Type: application/force-download");

			ob_clean();
			flush();
			readfile($result);
			exit();
    	}
		wp_redirect(admin_url('post.php?post='.$order->id.'&action=edit'));
		exit;
	}

 }